function newPaddedImage(filename)
    local source = love.image.newImageData(filename)
    local w, h = source:getWidth(), source:getHeight()
    
    -- Find closest power-of-two.
    local wp = math.pow(2, math.ceil(math.log(w)/math.log(2)))
    local hp = math.pow(2, math.ceil(math.log(h)/math.log(2)))
    
    -- Only pad if needed
    if wp ~= w or hp ~= h then
        local padded = love.image.newImageData(wp, hp)
        padded:paste(source, 0, 0)
        return love.graphics.newImage(padded)
    end
    
    return love.graphics.newImage(source)
end

function UnitVector(i,j)
	local m=math.sqrt(i^2+j^2)
return i/m,j/m,m
end

function DotProduct(Ax,Ay, Bi,Bj) -- cos()*lengthoftwovectors
	return Ax*Bi+Ay*Bj
end

function NewAnim(w,h,iw,ih,...)
local tbl={}
	for a=1,table.getn(arg) do
		table.insert(tbl,{})
		for f=1,arg[a] do
			table.insert(tbl[a], love.graphics.newQuad((f-1)*w,(a-1)*h, w,h, iw,ih))
		end
	end
return tbl
end

function RayTrace(x,y,i,j,m)
	local block=false
	--Ray Tracing backwards from player to enemy
	while not block and m > 0 do
		if not Map[RetTile(y+j*m)] or Map[RetTile(y+j*m)][RetTile(x+i*m)] ~= 240 then block=true end
		m=m-c_TileSize
	end
return block
end

function RayBox(bx,by,bi,bj,vx,vy,vi,vj,vm)
	local lx,ly=bx-vx,by-vy
	
	if (vx >= bx and vx <= bx+bi and vy >= by and vy <= by+bj)
	or (vx+vi*vm >= bx and vx+vi*vm <= bx+bi and vy >= by and vy <= by+bj)
	or (vx+vi*vm >= bx and vx+vi*vm <= bx+bi and vy+vj*vm >= by and vy+vj*vm <= by+bj)
	or (vx >= bx and vx <= bx+bi and vy+vj*vm >= by and vy+vj*vm <= by+bj)

	or (bx >= vx and bx <= vx+vi*vm and by >= vy and by <= vy+vj*vm)
	or (bx+bi >= vx and bx+bi <= vx+vi*vm and by >= vy and by <= vy+vj*vm)
	or (bx+bi >= vx and bx+bi <= vx+vi*vm and by+bj >= vy and by+bj <= vy+vj*vm)
	or (bx >= vx and bx <= vx+vi*vm and by+bj >= vy and by+bj <= vy+vj*vm)
	then
		return true
	end
end

function ZOrder(a,b)
  return a.y < b.y
end